@@ -1,6 +1,5 @@
-#!/usr/bin/env ruby
+# frozen_string_literal: true
 
-require "minitar"
 require "minitest_helper"
 
 class TestTarOutput < Minitest::Test
@@ -31,13 +30,12 @@ class TestTarOutput < Minitest::Test
 
   def test_file_looks_good
     Minitar::Output.open(@tarfile) do |os|
-      Dir.chdir("data__") do
-        NAMES.each do |name|
-          stat = File.stat(name)
-          opts = {:size => stat.size, :mode => 0o644}
-          os.tar.add_file_simple(name, opts) do |ss|
-            File.open(name, "rb") { |ff| ss.write(ff.read(4096)) until ff.eof? }
-          end
+      NAMES.each do |name|
+        filename = File.join("data__", name)
+        stat = File.stat(filename)
+        opts = {size: stat.size, mode: 0o644}
+        os.tar.add_file_simple(name, opts) do |ss|
+          File.open(filename, "rb") { |ff| ss.write(ff.read(4096)) until ff.eof? }
         end
       end
     end
@@ -46,9 +44,9 @@ class TestTarOutput < Minitest::Test
       names_from_tar = is.map do |entry|
         entry.name
       end
-      assert_equal(NAMES, names_from_tar)
+      assert_equal NAMES, names_from_tar
     end
   ensure
-    ff.close if ff
+    ff&.close
   end
 end
